#
# spec file for package python-oslo.cache
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global sname oslo.cache
Name:           python-oslo.cache
Version:        1.17.0
Release:        1.8
Summary:        Cache storage for Openstack projects
License:        Apache-2.0
Group:          Development/Languages/Python
Url:            http://launchpad.net/oslo
Source0:        https://pypi.io/packages/source/o/%{sname}/%{sname}-%{version}.tar.gz
BuildRequires:  openstack-macros
BuildRequires:  python-devel
BuildRequires:  python-dogpile.cache >= 0.6.2
BuildRequires:  python-mock >= 2.0
BuildRequires:  python-oslo.config >= 3.14.0
BuildRequires:  python-oslo.i18n >= 2.1.0
BuildRequires:  python-oslo.log >= 3.11.0
BuildRequires:  python-oslo.utils >= 3.18.0
BuildRequires:  python-oslotest >= 1.10.0
BuildRequires:  python-pbr >= 1.8
BuildRequires:  python-pymongo >= 3.0.2
BuildRequires:  python-python-memcached >= 1.56
BuildRequires:  python-six >= 1.9.0
Requires:       python-dogpile.cache >= 0.6.2
Requires:       python-oslo.config >= 3.14.0
Requires:       python-oslo.i18n >= 2.1.0
Requires:       python-oslo.log >= 3.11.0
Requires:       python-oslo.utils >= 3.18.0
Requires:       python-python-memcached >= 1.56
Requires:       python-six >= 1.9.0
BuildArch:      noarch

%description
oslo.cache aims to provide a generic caching mechanism for OpenStack projects
by wrapping the dogpile.cache library. The dogpile.cache library provides
support memoization, key value storage and interfaces to common caching
backends such as Memcached.

%package doc
Summary:        Documentation for the OpenStack Oslo Cache library
Group:          Development/Languages/Python
BuildRequires:  python-Sphinx
BuildRequires:  python-oslosphinx >= 4.7.0

%description doc
Documentation for the OpenStack Oslo cache library.

%prep
%autosetup -n %{sname}-%{version}
%py_req_cleanup

%build
%{py2_build}

%install
%{py2_install}

# generate html docs
%{__python2} setup.py build_sphinx
# remove the sphinx-build leftovers
rm -rf doc/build/html/.{doctrees,buildinfo}

%check
%{__python2} setup.py testr

%files
%license LICENSE
%doc README.rst ChangeLog
%{python2_sitelib}/oslo_cache
%{python2_sitelib}/*.egg-info

%files doc
%license LICENSE
%doc doc/build/html

%changelog
* Mon Feb 13 2017 cloud-devel@suse.de
- update to version 1.17.0:
  - Imported Translations from Zanata
  - Update reno for stable/newton
  - Remove references to Python 3.4
  - Fix docstring for get_memoization_decorator
  - Add Constraints support
  - Show team and repo badges on README
  - Changed the home-page link
  - Enable release notes translation
  - TrivialFix: Remove default=None when set value in Config
  - Updated from global requirements
  - Add usage example to documentation
* Thu Sep  1 2016 tbechtold@suse.com
- update to version 1.14.0
  * Correct help text for backend option
  * Fix OpenStack capitalization
* Tue Aug 30 2016 tbechtold@suse.com
- update to version 1.13.0
  * Updated from global requirements
* Wed Aug 10 2016 tbechtold@suse.com
- update to version 1.12.0
  * Fixup intersphinx docs
  * Use entrypoints for backends
  * Handle empty memcache pool corner case
  * Imported Translations from Zanata
  * Add Python 3.5 classifier and venv
  * Updated from global requirements
* Mon Jul  4 2016 tbechtold@suse.com
- update to 1.9.0:
  * Updated from global requirements
  * Add reno for releasenotes management
  * Trivial: ignore openstack/common in flake8 exclude list
  * Imported Translations from Zanata
  * Remove direct dependency on babel
  * If caching is globally disabled force dogpile to use the null backend
* Thu Jun  2 2016 tbechtold@suse.com
- use renderspec source service
- update spec from upstream
* Mon Apr  4 2016 tbechtold@suse.com
- update to 1.6.0:
  * Updated from global requirements
  * Update .gitreview for stable/mitaka
* Sun Mar 13 2016 dmueller@suse.com
- update to 1.5.0:
  * Updated from global requirements
* Thu Mar  3 2016 tbechtold@suse.com
- update to 1.4.0:
  * Updated from global requirements
  * Move some of these noisy logs to trace level
  * Revert "Use assertTrue/False instead of assertEqual(T/F)"
  * Update translation setup
  * Updated from global requirements
  * Updated from global requirements
  * Updated from global requirements
  * Updated from global requirements
  * Delete python bytecode before every test run
  * Use assertTrue/False instead of assertEqual(T/F)
  * Updated from global requirements
  * Replace deprecated LOG.warn with LOG.warning
  * Updated from global requirements
  * Updated from global requirements
  * Updated from global requirements
  * Trival: Remove 'MANIFEST.in'
  * Updated from global requirements
  * Remove Python 2.6 classifier
  * Remove python 2.6 and cleanup tox.ini
  * Updated from global requirements
  * Updated from global requirements
  * Updated from global requirements
  * Updated from global requirements
  * Export functions from __init__
- Adjust Requires according to requirements.txt
* Thu Oct 15 2015 dmueller@suse.com
- update to 0.8.0:
  * Make CacheIsolatingProxy public
  * Add shields.io version/downloads links/badges into README.rst
  * add auto-generated docs for config options
  * Change ignore-errors to ignore_errors
  * Updated from global requirements
* Thu Sep  3 2015 tbechtold@suse.com
- update to 0.7.0:
  * Updated from global requirements
  * Implement get/set/delete multiple keys for dictionary backend
* Thu Aug 27 2015 tbechtold@suse.com
- update to 0.6.0:
  * Move optional backend dependencies into setup.cfg [extras]
  * Ignore the .eggs/ directory
  * Remove remnants of noop backend registration
  * Updated from global requirements
  * Updated from global requirements
  * Setup translations
  * flake8 - remove unused rules and fix imports
  * Updated from global requirements
  * Updated from global requirements
  * Updated from global requirements
  * Remove NoOp cache from oslo.cache
- Adjust Requires according to requirements.txt
* Thu Jul 30 2015 tbechtold@suse.com
- Initial packaging
